# Roots Weather Project v2

Project Youtube Link : [@rWeather](https://www.youtube.com/@rWeather)

![Architecture Diagram](docs/images/RWDArchitecture.png)

![Build Workflow](https://github.com/johncanthony/RootsWeatherProject/actions/workflows/python-package.yml/badge.svg)
